/**
 * Ein rechteckiges Gitter von Positionen, an denen 0 oder 1 steht.
 * 
 * @author Ronald Ortner
 * @version 2015.01.16
 */
public class Welt
{
    // Laenge und die Breite des Feldes
    private int laenge, breite;
    
    // Feld als Array (0=unbesetzt, 1=besetzt)
    private int[][] welt;

    /**
     * Erzeuge Welt mit den angegebenen Dimensionen.
     * @param laenge die Laenge der Welt
     * @param breite die Breite der Welt
     */
    public Welt(int laenge, int breite)
    {
        this.laenge = laenge;
        this.breite = breite;
        welt = new int[laenge][breite];
    }
    
    /**
     * Leert das Feld
     */
    public void leere()
    {
        for(int zeile = 0; zeile < laenge; zeile++) {
            for(int spalte = 0; spalte < breite; spalte++) {
                welt[zeile][spalte] = 0;
            }
        }
    }
    
    
    /**
     * Gibt den Wert an der angegebenen Position zurueck
     * @param zeile die gewuenschte Zeile
     * @param spalte die gewuenschte Spalte
     * @return 0, wenn Feld unbesetzt; 1, wenn Feld besetzt
     */
    public int gibWelt(int zeile, int spalte)
    {
        return welt[zeile][spalte];
    }
    
    

    /**
     * Gibt die Anzahl der lebenden Nachbarzellen einer gegebenen Position zurueck. 
     * @param Koordinaten der Position, fuer die #Nachbarpositionen zurueckzugeben sind.
     * @return Anzahl der lebenden Nachbarzellen 
     */
    public int anzLebendeNachbarn(int zeile, int spalte)
    {
        int count = 0;
        
        for(int zDiff = -1; zDiff <= 1; zDiff++) {
            
            int naechsteZeile = zeile + zDiff;
            
            if(naechsteZeile >= 0 && naechsteZeile < laenge) {
                for(int sDiff = -1; sDiff <= 1; sDiff++) {
                    int naechsteSpalte = spalte + sDiff;
                    // Exclude invalid locations and the original location.
                    if(naechsteSpalte >= 0 && naechsteSpalte < breite && (zDiff != 0 || sDiff != 0)) {
                        if(welt[naechsteZeile][naechsteSpalte]==1)
                            count++;
                    }
                }
            }
        }
        return count;
    }
    
    /**
     * Setzt Wert an angegebener Position
     * @param Koordinaten der Position, Wert an der Position
     */
    public void set(int zeile, int spalte, int wert)
    {
        welt[zeile][spalte]=wert;
    }
    

    /**
     * Liefere die Laenge der Welt
     * @return die Laenge der Welt
     */
    public int gibLaenge()
    {
        return laenge;
    }
    
    /**
     * Liefere die Breite der Welt
     * @return die Breite der Welt
     */
    public int gibBreite()
    {
        return breite;
    }
}
